<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>AlertDialog</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>確定</translation>
    </message>
</context>
<context>
    <name>BackupWidget</name>
    <message>
        <source>Backing up…</source>
        <translation>備份中...</translation>
    </message>
    <message>
        <source>Backing up the current system, please wait patiently</source>
        <translation>系統升級前需要為您備份，請耐心等待</translation>
    </message>
</context>
<context>
    <name>BorderRadiusHeaderView</name>
    <message>
        <source>All</source>
        <translation>全選</translation>
    </message>
</context>
<context>
    <name>CheckImageResultWidget</name>
    <message>
        <source>File size:</source>
        <translation>鏡像大小</translation>
    </message>
    <message>
        <source>ISO version:</source>
        <translation>鏡像版本</translation>
    </message>
    <message>
        <source>%1 GB</source>
        <translation>%1 GB</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>檢查中</translation>
    </message>
    <message>
        <source>The image file is ready</source>
        <translation>鏡像已準備好</translation>
    </message>
    <message>
        <source>Some applications may not work properly after the upgrade.</source>
        <translation>升級後,部分應用可能出現無法正常使用等異常情況！</translation>
    </message>
    <message>
        <source>The upgrade may take a long time. Please plug in to avoid interruption.</source>
        <translation type="vanished">升級時間可能較長，請插上電源以免升級中斷</translation>
    </message>
    <message>
        <source>The version or integrity of the image file does not meet requirements.</source>
        <translation>鏡像版本或完整性不符</translation>
    </message>
</context>
<context>
    <name>CheckImageWidget</name>
    <message>
        <source>Verifying the integrity…</source>
        <translation>正在檢查鏡像完整性...</translation>
    </message>
</context>
<context>
    <name>CheckSizeThread</name>
    <message>
        <source>Unable to get the image file.</source>
        <translation>獲取鏡像失敗</translation>
    </message>
</context>
<context>
    <name>ConditionChecklistWidget</name>
    <message>
        <source>System version</source>
        <translation>系統版本</translation>
    </message>
    <message>
        <source>The system version is too old, and the upgrade may fail. To upgrade successfully, please update your system to the latest version in the Control Center first (you can ignore it and force an upgrade as well).</source>
        <translation>當前系統版本過低，存在升級失敗的風險！為保證升級成功率，請先通過控制中心-系統更新升級至最新操作系統（也可保持現狀強行升級）。</translation>
    </message>
    <message>
        <source>Requirement: deepin (%1)</source>
        <translation>基線要求：deepin (%1)</translation>
    </message>
    <message>
        <source>Requirement: Professional (%1)</source>
        <translation>基線要求：專業版 (%1)</translation>
    </message>
    <message>
        <source>Authorization status</source>
        <translation>系統激活狀態</translation>
    </message>
    <message>
        <source>Requirement: Activated</source>
        <translation>基線要求：激活</translation>
    </message>
    <message>
        <source>CPU architecture</source>
        <translation>CPU架構</translation>
    </message>
    <message>
        <source>Requirement: X86</source>
        <translation>基線要求：X86</translation>
    </message>
    <message>
        <source>Storage space</source>
        <translation>存儲空間</translation>
    </message>
    <message>
        <source>There are risks, but you can force an upgrade.</source>
        <translation>存在升級風險，但您可以強制升級</translation>
    </message>
    <message>
        <source>%1 (%2)</source>
        <translation>%1 (%2)</translation>
    </message>
    <message>
        <source>Too old</source>
        <translation>版本過低</translation>
    </message>
    <message>
        <source>Activated</source>
        <translation>已激活</translation>
    </message>
    <message>
        <source>Unactivated</source>
        <translation>未激活</translation>
    </message>
    <message>
        <source>Requirement: %1 GB</source>
        <translation>基線要求：%1 GB</translation>
    </message>
    <message>
        <source>Data disk %1 GB / %2 GB</source>
        <translation>數據盤 %1 GB/%2 GB</translation>
    </message>
    <message>
        <source>System disk %1 GB / %2 GB</source>
        <translation>系統盤 %1 GB/%2 GB</translation>
    </message>
</context>
<context>
    <name>DBusWorker</name>
    <message>
        <source>Backup failed</source>
        <translation>備份失敗</translation>
    </message>
    <message>
        <source>Upgrade failed</source>
        <translation>升級失敗</translation>
    </message>
    <message>
        <source>Restoration failed</source>
        <translation>還原失敗</translation>
    </message>
</context>
<context>
    <name>FileDownloader</name>
    <message>
        <source>URL &quot;%1&quot; is illegal</source>
        <translation>“%1”為非法地址</translation>
    </message>
</context>
<context>
    <name>ImageDownloadWidget</name>
    <message>
        <source>Downloading the V23 image file</source>
        <translation>正在下載V23鏡像</translation>
    </message>
    <message>
        <source>You can continue using the computer without being affected</source>
        <translation>你可以繼續使用電腦，絲毫不受影響</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Time remaining: %1 / File size: %2 GB</source>
        <translation>預計剩餘時間：%1  /  鏡像大小：%2 GB</translation>
    </message>
</context>
<context>
    <name>ImagePreparationWidget</name>
    <message>
        <source>Download failed</source>
        <translation>下載失敗</translation>
    </message>
    <message>
        <source>Do you want to exit the downloading?</source>
        <translation>確定退出鏡像下載嗎？</translation>
    </message>
    <message>
        <source>Do you want to exit the image file checking?</source>
        <translation>確定退出鏡像檢查嗎？</translation>
    </message>
    <message>
        <source>Start Upgrade</source>
        <translation>去升級</translation>
    </message>
    <message>
        <source>Reselect</source>
        <translation>重新獲取</translation>
    </message>
    <message>
        <source>Errors:</source>
        <translation>錯誤信息：</translation>
    </message>
    <message>
        <source>Error code:</source>
        <translation>錯誤碼：</translation>
    </message>
    <message>
        <source>Failed to connect to the server. Please check your network connection or select a local V23 image file.</source>
        <translation>無法連接服務器！請檢查網絡連接或者選擇本地V23鏡像文件</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一步</translation>
    </message>
    <message>
        <source>Your computer is not plugged in, please plug in a power cord first and then upgrade.</source>
        <translation>您未連接電源，請連接電源再升級</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <source>Do you want to exit software evaluation?</source>
        <translation>確定退出軟件評估嗎？</translation>
    </message>
    <message>
        <source>Software evaluation failed</source>
        <translation>軟件評估失敗</translation>
    </message>
</context>
<context>
    <name>InitialWidget</name>
    <message>
        <source>Deepin Upgrade</source>
        <translation type="vanished">Deepin系統升級</translation>
    </message>
    <message>
        <source>Current version: V%1</source>
        <translation>當前版本：V%1</translation>
    </message>
    <message>
        <source>Take a few simple steps to upgrade your system to</source>
        <translation>只需一些簡單的操作即可幫助您的計算機升級至</translation>
    </message>
    <message>
        <source>Deepin 23</source>
        <translation type="vanished">Deepin 23</translation>
    </message>
    <message>
        <source>I have read and agreed to the </source>
        <translation type="vanished">我已閱讀並同意</translation>
    </message>
    <message>
        <source>《Deepin系統升級工具》</source>
        <translation type="vanished">《Deepin系統升級工具》</translation>
    </message>
    <message>
        <source>Pre-Check</source>
        <translation>升級檢查</translation>
    </message>
    <message>
        <source>Deepin Upgrade Tool</source>
        <translation type="vanished">Deepin系統升級工具</translation>
    </message>
    <message>
        <source>Disagree</source>
        <translation>不同意</translation>
    </message>
    <message>
        <source>Agree</source>
        <translation>同意</translation>
    </message>
    <message>
        <source>End User License Agreement for Deepin Upgrade Tool</source>
        <translatorcomment>標題</translatorcomment>
        <translation>Deepin系統升級工具軟件最終用戶許可協議</translation>
    </message>
    <message>
        <source>:/text/end_user_license_en.txt</source>
        <translation>:/text/end_user_license_zh_CN.txt</translation>
    </message>
    <message>
        <source>Privacy Protection Guide for Deepin Upgrade Tool</source>
        <translatorcomment>標題</translatorcomment>
        <translation>Deepin系統升級工具軟件隱私保護指引</translation>
    </message>
    <message>
        <source>:/text/privacy_protection_guide_en.txt</source>
        <translation>:/text/privacy_protection_guide_zh_CN.txt</translation>
    </message>
    <message>
        <source>End User License Agreement for Deepin Upgrade Tool.</source>
        <translatorcomment>用戶協議標籤名</translatorcomment>
        <translation type="vanished">《Deepin系統升級工具軟件最終用戶許可協議》。</translation>
    </message>
    <message>
        <source>Privacy Protection Guide for Deepin Upgrade Tool.</source>
        <translatorcomment>隱私標籤名</translatorcomment>
        <translation type="vanished">《Deepin系統升級工具軟件隱私保護指引》。</translation>
    </message>
    <message>
        <source>&quot;End User License Agreement for Deepin Upgrade Tool&quot;</source>
        <translatorcomment>勾選框文字標題。</translatorcomment>
        <translation>《最終用戶許可協議》</translation>
    </message>
    <message>
        <source>&quot;Privacy Protection Guide&quot;</source>
        <translation>《隱私保護指引》</translation>
    </message>
    <message>
        <source>I have read and agreed to the &lt;a href=&quot;user&quot; style=&quot;text-decoration: none;&quot;&gt;%1&lt;/a&gt; and &lt;a href=&quot;privacy&quot; style=&quot;text-decoration: none;&quot;&gt;%2&lt;/a&gt;.</source>
        <translation>我已閱讀並同意&lt;a href=&quot;user&quot; style=&quot;text-decoration: none;&quot;&gt;%1&lt;/a&gt;和&lt;a href=&quot;privacy&quot; style=&quot;text-decoration: none;&quot;&gt;%2&lt;/a&gt;。</translation>
    </message>
    <message>
        <source>System Upgrade Tool</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>deepin 23</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Do you want to exit the Deepin Upgrade Tool?</source>
        <translation>確定退出Deepin系統升級工具嗎？</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Upgrade failed</source>
        <translation>升級失敗</translation>
    </message>
</context>
<context>
    <name>MigrateFinishedWidget</name>
    <message>
        <source>App migration successful</source>
        <translation>應用遷移成功</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>確定</translation>
    </message>
</context>
<context>
    <name>MigrateProgressWidget</name>
    <message>
        <source>Migrating apps</source>
        <translation>應用遷移中</translation>
    </message>
    <message>
        <source>Migrating apps, please wait patiently</source>
        <translation>應用遷移中，請耐心等候</translation>
    </message>
    <message>
        <source>Reconnect</source>
        <translation>重新連接</translation>
    </message>
    <message>
        <source>Network error. App migration has been interrupted.</source>
        <translation>網絡異常，應用遷移已中斷</translation>
    </message>
    <message>
        <source>Network connection failed. Please check your network.</source>
        <translation>連接不到網絡，請檢查您的網絡</translation>
    </message>
</context>
<context>
    <name>MigrateWidget</name>
    <message>
        <source>App migration failed</source>
        <translation>應用遷移失敗</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation>反饋</translation>
    </message>
</context>
<context>
    <name>ProgressWidget</name>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Time remaining: %1</source>
        <translation>預計剩餘時間：%1</translation>
    </message>
</context>
<context>
    <name>RestorationWidget</name>
    <message>
        <source>Restoring…</source>
        <translation>系統還原中...</translation>
    </message>
    <message>
        <source>Upgrade failed. Your system is being restored to the previous version.</source>
        <translation>系統升級失敗，正在為您還原系統，請稍侯</translation>
    </message>
</context>
<context>
    <name>RetrieveImageMethodWidget</name>
    <message>
        <source>Get Image Files</source>
        <translation>請選擇鏡像獲取方式</translation>
    </message>
    <message>
        <source>Download from Internet</source>
        <translation>聯網下載</translation>
    </message>
    <message>
        <source>Import local image files</source>
        <translation>本地導入鏡像文件</translation>
    </message>
    <message>
        <source>Format: ISO</source>
        <translation>只支持擴展名：ISO</translation>
    </message>
    <message>
        <source>Drag files here</source>
        <translation>拖拽文件至此處</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>選擇文件</translation>
    </message>
</context>
<context>
    <name>SoftwareCheckProgressWidget</name>
    <message>
        <source>Pre-Check</source>
        <translation type="obsolete">升級檢查</translation>
    </message>
    <message>
        <source>Check your computer to see if it meets the upgrade conditions</source>
        <translation type="obsolete">升級前，需檢查是否滿足升級的基本條件</translation>
    </message>
    <message>
        <source>Software Evaluation</source>
        <translation>軟件評估</translation>
    </message>
    <message>
        <source>Evaluate the compatibility of installed apps in the new system</source>
        <translation>評估已安裝軟件在新系統中的兼容性</translation>
    </message>
</context>
<context>
    <name>SoftwareEvaluationOfflineWidget</name>
    <message>
        <source>Software Evaluation</source>
        <translation>軟件評估</translation>
    </message>
    <message>
        <source>Your current usage scenario is in a state of no network. We cannot evaluate the software you are using. After the upgrade is complete, the software you are currently installing needs to be reinstalled. If you want to view the details of the applications that can be installed for the upgrade, please upgrade online</source>
        <translation>您當前的使用場景處於無網絡狀態，我們無法對你正在使用的軟件進行評估，升級完成後您當前所安裝的軟件需要重新進行安裝，如需查看升級可安裝應用詳情請聯網升級</translation>
    </message>
</context>
<context>
    <name>SoftwareEvaluationWidget</name>
    <message>
        <source>Compatible</source>
        <translation type="vanished">兼容</translation>
    </message>
    <message>
        <source>Incompatible</source>
        <translation type="vanished">不兼容</translation>
    </message>
    <message>
        <source>Evaluation Result</source>
        <translation>軟件評估結果</translation>
    </message>
    <message>
        <source>The upgrade may take a long time. Please plug in to avoid interruption.</source>
        <translation>升級時間可能較長，請插上電源以免升級中斷</translation>
    </message>
    <message>
        <source>Compatible Apps</source>
        <translation>兼容應用</translation>
    </message>
    <message>
        <source>Incompatible Apps</source>
        <translation>不兼容應用</translation>
    </message>
    <message>
        <source>V23 version supports applications</source>
        <translation type="vanished">V23版本支持應用</translation>
    </message>
    <message>
        <source>The V23 version does not support the application</source>
        <translation type="vanished">V23版本不支持應用</translation>
    </message>
    <message>
        <source>The system upgrade will ensure the integrity of user data, and we will not delete user data</source>
        <translation>系統升級會保證用戶數據的完整性，我們不會對用戶數據進行刪減</translation>
    </message>
    <message>
        <source>By default, the cross-version upgrade does not migrate the installed applications. After the upgrade is completed, the system will automatically install the selected applications in the list. Please select the software that needs to be installed after the upgrade is complete</source>
        <translation type="vanished">跨版本升級默認不對已安裝應用進行遷移，完成升級後系統會對列表勾選應用進行自動化安裝，請選擇升級完成後需要安裝的應用</translation>
    </message>
    <message>
        <source>The cross-version upgrade does not migrate the application. After the upgrade is completed, it supports automatic installation of the selected compatible application</source>
        <translation>跨版本升級不對應用進行遷移，升級完成後支持對已勾選兼容應用自動化安裝</translation>
    </message>
</context>
<context>
    <name>StorageResultWidget</name>
    <message>
        <source>Free up</source>
        <translation>清理</translation>
    </message>
    <message>
        <source>Your system cannot be upgraded to V23</source>
        <translation>當前空間不支持升級V23！</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>確定</translation>
    </message>
    <message>
        <source>Clean system disk</source>
        <translation>清理系統盤</translation>
    </message>
    <message>
        <source>%1 GB free space required</source>
        <translation>系統盤還需要%1 GB空間</translation>
    </message>
    <message>
        <source>Free Up</source>
        <translation>去清理</translation>
    </message>
    <message>
        <source>Clean data disk</source>
        <translation>清理數據盤</translation>
    </message>
    <message>
        <source>System backup only, no app backup</source>
        <translation type="vanished">僅備份系統，不備份應用</translation>
    </message>
    <message>
        <source>Less disk space is required if enabled, but some apps may not work properly after restoring the system from version 23.</source>
        <translation type="vanished">開啟此功能將降低備份空間要求，但從V23還原至當前系統時，部分應用可能不可用</translation>
    </message>
</context>
<context>
    <name>SystemUpgradeWidget</name>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>重新備份</translation>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation>反饋</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>備份失敗</translation>
    </message>
    <message>
        <source>Restoration failed</source>
        <translation>還原失敗</translation>
    </message>
    <message>
        <source>After clicking restart, the system will be upgraded, please save the current running application data before confirming</source>
        <translation>點擊重啟後系統將進行升級，確認前請對當前運行應用數據進行保存</translation>
    </message>
    <message>
        <source>Restart now</source>
        <translation>立即重啟</translation>
    </message>
</context>
<context>
    <name>UpgradeCheckProgressWidget</name>
    <message>
        <source>Pre-Check</source>
        <translation>升級檢查</translation>
    </message>
    <message>
        <source>Check your computer to see if it meets the upgrade conditions</source>
        <translation>升級前，需檢查是否滿足升級的基本條件</translation>
    </message>
</context>
<context>
    <name>UpgradeCheckResultWidget</name>
    <message>
        <source>Check Conditions</source>
        <translation type="vanished">條件檢查</translation>
    </message>
    <message>
        <source>Software Changes</source>
        <translation type="vanished">軟件評估</translation>
    </message>
    <message>
        <source>Passed</source>
        <translation>檢查通過</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>檢查未通過</translation>
    </message>
</context>
<context>
    <name>UpgradeCheckWidget</name>
    <message>
        <source>Do you want to exit the pre-upgrade checking?</source>
        <translation>確定退出升級檢查嗎？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Check Again</source>
        <translation>重新檢查</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一步</translation>
    </message>
</context>
<context>
    <name>UpgradeWidget</name>
    <message>
        <source>Upgrading…</source>
        <translation>系統升級中...</translation>
    </message>
    <message>
        <source>Preparing for system upgrade, please wait patiently</source>
        <translation>系統升級準備中,請耐心等候</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Deepin Upgrade Tool</source>
        <translation>Deepin系統升級工具</translation>
    </message>
    <message>
        <source>Deepin Upgrade Tool helps you upgrade the system to version 23.</source>
        <translation>Deepin系統升級工具是一款將系統升級為V23的小工具。</translation>
    </message>
    <message>
        <source>Upgrade successful</source>
        <translation>系統升級成功</translation>
    </message>
    <message>
        <source>Successfully upgraded to version %1</source>
        <translation>已成功升級至V%1系統</translation>
    </message>
    <message>
        <source>Error code: %1</source>
        <translation>錯誤碼：%1</translation>
    </message>
</context>
</TS>
